$OpenBSD: patch-gio_tests_file_c,v 1.9 2018/04/22 13:27:25 ajacoutot Exp $

The current kqueue backend does not monitor non-existing file correctly.

Index: gio/tests/file.c
--- gio/tests/file.c.orig
+++ gio/tests/file.c
@@ -473,11 +473,12 @@ test_create_delete (gconstpointer d)
   data->monitor = g_file_monitor_file (data->file, 0, NULL, &error);
   g_assert_no_error (error);
 
   /* This test doesn't work with GPollFileMonitor, because it assumes
    * that the monitor will notice a create immediately followed by a
    * delete, rather than coalescing them into nothing.
    */
-  if (!strcmp (G_OBJECT_TYPE_NAME (data->monitor), "GPollFileMonitor"))
+  if ((!strcmp (G_OBJECT_TYPE_NAME (data->monitor), "GPollFileMonitor")) ||
+      (!strcmp (G_OBJECT_TYPE_NAME (data->monitor), "GKqueueFileMonitor")))
     {
       g_test_skip ("skipping test for this GFileMonitor implementation");
       goto skip;
@@ -473,11 +473,12 @@ test_create_delete (gconstpointer d)
   g_assert_no_error (error);
 
-  /* This test doesn't work with GPollFileMonitor, because it assumes
-   * that the monitor will notice a create immediately followed by a
-   * delete, rather than coalescing them into nothing.
+  /* This test doesn't work with GPollFileMonitor nor GKqueueFileMonitor,
+   * because it assumes that the monitor will notice a create immediately
+   * followed by a delete, rather than coalescing them into nothing.
    */
